@@ -18,7 +18,7 @@ All named fields are required.
 
 =head1 METHODS
 
-=head2 $self->process( $widget, $params )
+=head2 process
 
 =cut
 
@@ -27,9 +27,11 @@ sub process {
     my $results = [];
     for my $name ( @{ $self->names } ) {
         push @$results,
-          HTML::Widget::Error->new(
+            HTML::Widget::Error->new(
             { name => $name, message => $self->mk_message } )
-          if $self->not ? (defined $params->{$name} && length $params->{$name}) : (!defined $params->{$name} || !length($params->{$name}) );
+            if $self->not
+            ? ( defined $params->{$name} && length $params->{$name} )
+            : ( !defined $params->{$name} || !length( $params->{$name} ) );
     }
     return $results;
 }
