@@ -2,14 +2,9 @@ package HTML::Widget::Element::Reset;
 
 use warnings;
 use strict;
-use base 'HTML::Widget::Element';
+use base 'HTML::Widget::Element::Button';
 use NEXT;
 
-__PACKAGE__->mk_accessors(qw/value/);
-
-# alias
-*label = \&value;
-
 =head1 NAME
 
 HTML::Widget::Element::Reset - Reset Element
@@ -21,38 +16,36 @@ HTML::Widget::Element::Reset - Reset Element
 
 =head1 DESCRIPTION
 
-Reset Element.
+Reset button element.
+
+Inherits all methods from L<HTML::Widget::Element::Button>.
+
+Automatically sets L<type|HTML::Widget::Element::Button/type> to C<reset>.
 
 =head1 METHODS
 
-=head2 value
+=head2 new
+
+=cut
+
+sub new {
+    return shift->NEXT::new(@_)->type('reset');
+}
 
 =head2 label
 
-The value of this Reset element. Is also used by the browser as the 
+=head2 value
+
+Sets the form field value. Is also used by the browser as the 
 button label.
 
 If not set, the browser will usually display the label as "Reset".
 
 L</label> is an alias for L</value>.
 
-=head2 containerize
-
-=cut
-
-sub containerize {
-    my ( $self, $w, $value, $errors, $args ) = @_;
-
-    $value = $self->value if ( not defined $value ) and not $args->{submitted};
-
-    my $i = $self->mk_input( $w, { type => 'reset', value => $value } );
-
-    return $self->container( { element => $i } );
-}
-
 =head1 SEE ALSO
 
-L<HTML::Widget::Element>
+L<HTML::Widget::Element::Button>, L<HTML::Widget::Element>
 
 =head1 AUTHOR
 
