@@ -9,7 +9,10 @@ use HTML::Widget::Error;
 *constrain_values = \&constrain_options;
 
 __PACKAGE__->mk_accessors(
-    qw/comment label multiple options selected constrain_options/);
+    qw/comment label multiple options selected constrain_options
+        retain_default/
+);
+
 __PACKAGE__->mk_attr_accessors(qw/size/);
 
 =head1 NAME
@@ -83,6 +86,12 @@ automatically be added to the widget, using the key names from L</options>.
 
 L</constrain_values> is an alias for L</constrain_options>.
 
+=head2 retain_default
+
+If true, overrides the default behaviour, so that after a field is missing 
+from the form submission, the xml output will contain the default value, 
+rather than be empty.
+
 =head2 prepare
 
 =cut
@@ -140,7 +149,7 @@ sub containerize {
     if ( defined $value ) {
         @values = ref $value eq 'ARRAY' ? @$value : ($value);
     }
-    elsif ( !$args->{submitted} ) {
+    elsif ( $self->retain_default || !$args->{submitted} ) {
         @values =
             ref $self->selected eq 'ARRAY'
             ? @{ $self->selected }
