@@ -27,7 +27,7 @@ C<content()> can contain a string, an
 L<HTML::Element|HTML::Element> object, or an array-ref of 
 L<HTML::Element|HTML::Element> objects.
 
-=head2 $self->containerize( $widget, $value )
+=head2 containerize
 
 =cut
 
@@ -37,15 +37,38 @@ sub containerize {
     my $content = $self->content;
     $self->attributes->{class} ||= 'span';
     my $e = HTML::Element->new( 'span', id => $self->id($w) );
-    my @content = ($content && ref($content) eq 'ARRAY') ? @$content : ($content)
+    my @content
+        = ( $content && ref($content) eq 'ARRAY' ) ? @$content : ($content)
         if defined $content;
     $e->push_content(@content) if @content;
     $e->attr( $_ => ${ $self->attributes }{$_} )
-      for ( keys %{ $self->attributes } );
+        for ( keys %{ $self->attributes } );
 
     return $self->container( { element => $e } );
 }
 
+=head2 new
+
+Sets L<HTML::Widget::Element/allow_filter> to false, so that filters added 
+by C<< $widget->filter_all >> won't be applied to Span elements.
+
+Sets L<HTML::Widget::Element/allow_constraint> to false, so that constraints 
+added by C<< $widget->constraint_all >> won't be applied to Span elements.
+
+=cut
+
+sub new {
+    my $self = shift->NEXT::new(@_);
+
+    $self->allow_filter(0)->allow_constraint(0);
+
+    return $self;
+}
+
+=head1 SEE ALSO
+
+L<HTML::Widget::Element>
+
 =head1 AUTHOR
 
 Sebastian Riedel, C<sri@oook.de>
